@@ -25,6 +25,8 @@ if TYPE_CHECKING:
 
 
 class AppiumConnection(RemoteConnection):
+    _proxy_url: Optional[str]
+
     def __init__(
         self,
         remote_server_addr: str,
@@ -32,7 +34,6 @@ class AppiumConnection(RemoteConnection):
         ignore_proxy: Optional[bool] = False,
         init_args_for_pool_manager: Union[Dict[str, Any], None] = None,
     ):
-
         # Need to call before super().__init__ in order to pass arguments for the pool manager in the super.
         self._init_args_for_pool_manager = init_args_for_pool_manager or {}
 
@@ -40,7 +41,7 @@ class AppiumConnection(RemoteConnection):
 
     def _get_connection_manager(self) -> Union[urllib3.PoolManager, urllib3.ProxyManager]:
         # https://github.com/SeleniumHQ/selenium/blob/0e0194b0e52a34e7df4b841f1ed74506beea5c3e/py/selenium/webdriver/remote/remote_connection.py#L134
-        pool_manager_init_args = {'timeout': self._timeout}
+        pool_manager_init_args = {'timeout': self.get_timeout()}
 
         if self._ca_certs:
             pool_manager_init_args['cert_reqs'] = 'CERT_REQUIRED'
@@ -51,11 +52,17 @@ class AppiumConnection(RemoteConnection):
 
         pool_manager_init_args.update(self._init_args_for_pool_manager)
 
-        return (
-            urllib3.PoolManager(**pool_manager_init_args)
-            if self._proxy_url is None
-            else urllib3.ProxyManager(self._proxy_url, **pool_manager_init_args)
-        )
+        if self._proxy_url:
+            if self._proxy_url.lower().startswith('sock'):
+                from urllib3.contrib.socks import SOCKSProxyManager
+
+                return SOCKSProxyManager(self._proxy_url, **pool_manager_init_args)
+            if self._identify_http_proxy_auth():
+                self._proxy_url, self._basic_proxy_auth = self._separate_http_proxy_auth()
+                pool_manager_init_args['proxy_headers'] = urllib3.make_headers(proxy_basic_auth=self._basic_proxy_auth)
+            return urllib3.ProxyManager(self._proxy_url, **pool_manager_init_args)
+
+        return urllib3.PoolManager(**pool_manager_init_args)
 
     @classmethod
     def get_remote_connection_headers(cls, parsed_url: 'ParseResult', keep_alive: bool = True) -> Dict[str, Any]:
